"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.bootstrap = void 0;
const typedoc_1 = require("typedoc");
const theme_1 = require("../theme");
const declarations = __importStar(require("./options/declarations"));
const renderer_1 = require("./renderer");
/**
 * Exposes required functionality to TypeDoc.
 */
function bootstrap(app) {
    /**
     * ====================
     * 1. Bootstrap Options
     * ====================
     */
    /**
     * Interate over declaration definitions and to the container.
     */
    Object.entries(declarations).forEach(([name, declaration]) => {
        app.options.addDeclaration({
            name,
            ...declaration,
        });
    });
    /**
     * =================================================
     * 2. Intercept and modify some TypeDoc core methods
     * =================================================
     *
     * Currently the TypeDoc {@link Renderer} class is quite coupled to the HTML theme so we override a couple of core methods.
     *
     * @todo Ideally there would be proper decoupling in the TypeDoc core between the {@link Application} and {@link Renderer} which requires further investigation.
     *
     */
    /**
     * Replace the default HTML theme the with the {@link MarkdownTheme}
     */
    Object.defineProperty(app.renderer, 'themes', {
        value: new Map([
            ['default', theme_1.MarkdownTheme],
        ]),
    });
    /**
     * Replace TypeDoc's {@link app.generateDocs} method with our own {@link generateDocs} method.
     */
    Object.defineProperty(app, 'generateDocs', { value: renderer_1.generateDocs });
    /**
     * Replace TypeDoc's {@link app.renderer.render} method with our own {@link render} method.
     */
    Object.defineProperty(app.renderer, 'render', {
        value: renderer_1.render,
    });
    /**
     * Add a new {@link MarkdownRendererHooks} property to the {@link MarkdownRenderer} class.
     * This is used to hook into the TypeDoc rendering system.
     */
    Object.defineProperty(app.renderer, 'markdownHooks', {
        value: new typedoc_1.EventHooks(),
    });
    /**
     * ============================
     * 3. Apply any other behaviour
     * ============================
     */
    /**
     * Currently options set for packages are only stored on the converter and are destroyed before being passed to the {@link Renderer}.
     *
     * By intercepting the package options set in the converter and storing them on the renderer we can use them later in the theme.
     *
     * @todo Ideally this functionality would be available in TypeDoc core - to investigate.
     */
    app.converter.on(typedoc_1.Converter.EVENT_RESOLVE_END, (context) => {
        if (app.options.packageDir) {
            const renderer = app.renderer;
            renderer.packageOptions = {
                ...(renderer.packageOptions || {}),
                [context.project.name]: app.options,
            };
        }
    });
}
exports.bootstrap = bootstrap;
