"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getNavigation = void 0;
const path = __importStar(require("path"));
const typedoc_1 = require("typedoc");
const option_maps_1 = require("../../plugin/options/option-maps");
function getNavigation(theme, project) {
    const options = theme.application.options;
    const navigation = [];
    const optionsForPackages = theme.application.renderer.packageOptions;
    const isPackages = options.getValue('entryPointStrategy') === typedoc_1.EntryPointStrategy.Packages;
    if (isPackages) {
        if (Object.keys(optionsForPackages)?.length === 1) {
            buildNavigationFromProject(project);
        }
        else {
            project.children?.forEach((projectChild) => {
                buildNavigationFromPackage(projectChild);
            });
        }
    }
    else {
        buildNavigationFromProject(project);
    }
    return navigation;
    function buildNavigationFromPackage(projectChild) {
        const entryFileName = options.getValue('entryFileName');
        const preservePackageReadme = Boolean(projectChild.readme) && !options.getValue('mergeReadme');
        const packageOptions = optionsForPackages[projectChild.name];
        const isSet = packageOptions.isSet('outputFileStrategy');
        const outputFileStrategy = isSet
            ? packageOptions.getValue('outputFileStrategy')
            : options.getValue('outputFileStrategy');
        const projectChildUrl = preservePackageReadme
            ? `${path.dirname(projectChild.url)}/${entryFileName}`
            : projectChild.url;
        const isModulesGroup = projectChild?.groups &&
            projectChild?.groups[0].children.every((child) => child.kindOf(typedoc_1.ReflectionKind.Module));
        const children = [];
        if (preservePackageReadme &&
            !isModulesGroup &&
            outputFileStrategy === option_maps_1.OutputFileStrategy.Modules) {
            children.push({
                title: theme.getText('label.globals'),
                url: projectChild.url,
            });
        }
        const childGroups = getChildrenOrGroups(projectChild, outputFileStrategy);
        if (childGroups) {
            children.push(...childGroups);
        }
        navigation.push({
            title: projectChild.name,
            children,
            ...(projectChildUrl && { url: projectChildUrl }),
        });
    }
    function buildNavigationFromProject(project) {
        const entryModule = options.getValue('entryModule');
        if (project.groups?.length) {
            const isEntryModule = Boolean(project?.groups[0]?.children.find((child) => child.name === entryModule));
            const isOnlyModules = project.children?.every((child) => child.kindOf(typedoc_1.ReflectionKind.Module));
            if ((project.groups.length === 1 && !Boolean(isEntryModule)) ||
                isOnlyModules) {
                const children = getGroupChildren(project.groups[0]);
                if (children) {
                    navigation.push(...children.filter((child) => child.title !== entryModule));
                }
            }
            else {
                project.groups?.forEach((projectGroup) => {
                    const children = getGroupChildren(projectGroup);
                    const indexModule = projectGroup.children.find((child) => child.name === entryModule);
                    if (children.length) {
                        navigation.push({
                            title: projectGroup.title,
                            children: children.filter((child) => child.title !== entryModule),
                        });
                    }
                    if (indexModule) {
                        const children = getChildrenOrGroups(indexModule);
                        if (children) {
                            navigation.push(...children);
                        }
                    }
                });
            }
        }
    }
    function getCategoryGroupChildren(group) {
        return group.children
            ?.filter((child) => child.hasOwnDocument)
            .map((child) => {
            const children = getChildrenOrGroups(child);
            return {
                title: child.name,
                url: child.url,
                ...(children && { children }),
            };
        });
    }
    function getGroupChildren(group, outputFileStrategy) {
        if (group?.categories?.length) {
            return group.categories?.map((category) => {
                return {
                    title: category.title,
                    children: getCategoryGroupChildren(category),
                };
            });
        }
        return group.children
            ?.filter((child) => child.hasOwnDocument)
            .map((child) => {
            const mapping = theme.getTemplateMapping(child.kind, outputFileStrategy);
            if (Boolean(mapping)) {
                const children = child.categories?.length
                    ? child.categories
                        ?.map((category) => {
                        const catChildren = getCategoryGroupChildren(category);
                        return catChildren.length
                            ? {
                                title: category.title,
                                children: catChildren,
                            }
                            : null;
                    })
                        .filter((cat) => Boolean(cat))
                    : getChildrenOrGroups(child, outputFileStrategy);
                return {
                    title: child.name,
                    url: child.url,
                    ...(children && { children }),
                };
            }
        });
    }
    function getChildrenOrGroups(reflection, outputFileStrategy) {
        if (reflection.groups?.some((group) => group.allChildrenHaveOwnDocument())) {
            if (options.getValue('excludeGroups')) {
                return reflection.children
                    ?.filter((child) => child.hasOwnDocument)
                    .map((child) => {
                    const children = getChildrenOrGroups(child, outputFileStrategy);
                    return {
                        title: child.name,
                        url: child.url,
                        ...(children && { children }),
                    };
                });
            }
            const isModulesGroup = reflection.groups[0].children.every((child) => child.kindOf(typedoc_1.ReflectionKind.Module));
            if (isModulesGroup) {
                return (getGroupChildren(reflection.groups[0], outputFileStrategy) || null);
            }
            return reflection.groups
                ?.map((group) => {
                const groupChildren = getGroupChildren(group, outputFileStrategy);
                return groupChildren.length
                    ? {
                        title: theme.getTextFromKindString(group.title, true),
                        children: groupChildren || null,
                    }
                    : null;
            })
                .filter((group) => Boolean(group));
        }
        return null;
    }
}
exports.getNavigation = getNavigation;
