"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getUrls = void 0;
const path = __importStar(require("path"));
const typedoc_1 = require("typedoc");
const option_maps_1 = require("../../plugin/options/option-maps");
/**
 * Map the models of the given project to the desired output files.
 * Based on TypeDoc DefaultTheme.getUrls()
 *
 * @param project  The project whose urls should be generated.
 */
function getUrls(theme, project) {
    const options = theme.application.options;
    const optionsForPackages = theme.application.renderer.packageOptions;
    const urls = [];
    const anchors = {};
    const preserveReadme = Boolean(project.readme) && !options.getValue('mergeReadme');
    const isModulesOnly = project.children?.every((child) => child.kindOf(typedoc_1.ReflectionKind.Module));
    const useEntryModule = project?.groups &&
        Boolean(project?.groups[0]?.children.find((child) => child.name === options.getValue('entryModule'))) &&
        isModulesOnly;
    const isPackages = options.getValue('entryPointStrategy') === typedoc_1.EntryPointStrategy.Packages;
    const entryFileName = options.getValue('entryFileName');
    const indexFilename = getIndexFileName(project, isPackages);
    project.url = preserveReadme
        ? indexFilename
        : useEntryModule
            ? indexFilename
            : options.getValue('entryFileName');
    if (preserveReadme) {
        urls.push({
            url: useEntryModule ? 'readme_.md' : entryFileName,
            model: project,
            template: theme.readmeTemplate,
        });
        if (!useEntryModule) {
            urls.push({
                url: indexFilename,
                model: project,
                template: theme.projectTemplate,
            });
        }
    }
    else {
        if (!useEntryModule) {
            urls.push({
                url: entryFileName,
                model: project,
                template: theme.projectTemplate,
            });
        }
    }
    if (isPackages) {
        if (Object.keys(optionsForPackages)?.length === 1) {
            buildUrlsFromProject(project);
        }
        else {
            project.children?.forEach((projectChild) => {
                buildUrlsFromPackage(projectChild);
            });
        }
    }
    else {
        buildUrlsFromProject(project);
    }
    return urls;
    function buildUrlsFromProject(project, parentUrl, outputFileStrategy) {
        project.groups?.forEach((projectGroup) => {
            projectGroup.children?.forEach((projectGroupChild) => {
                buildUrlsFromGroup(projectGroupChild, {
                    ...(parentUrl && { parentUrl }),
                    ...(outputFileStrategy && { outputFileStrategy }),
                });
            });
        });
    }
    function buildUrlsFromPackage(projectChild) {
        const entryFileName = options.getValue('entryFileName');
        const preservePackageReadme = Boolean(projectChild.readme) && !options.getValue('mergeReadme');
        const packagesIndex = getIndexFileName(projectChild);
        const packageOptions = optionsForPackages[projectChild.name];
        const isSet = packageOptions.isSet('outputFileStrategy');
        const outputFileStrategy = isSet
            ? packageOptions.getValue('outputFileStrategy')
            : options.getValue('outputFileStrategy');
        const url = `${projectChild.name}/${preservePackageReadme ? packagesIndex : entryFileName}`;
        if (preservePackageReadme) {
            urls.push({
                url: `${path.dirname(url)}/${entryFileName}`,
                model: projectChild,
                template: theme.readmeTemplate,
            });
        }
        urls.push({
            url: url,
            model: projectChild,
            template: theme.projectTemplate,
        });
        projectChild.url = url;
        buildUrlsFromProject(projectChild, url, outputFileStrategy);
    }
    function buildUrlsFromGroup(reflection, options) {
        const mapping = theme.getTemplateMapping(reflection.kind, options.outputFileStrategy);
        if (mapping) {
            const directory = options.directory || mapping.directory;
            const urlPath = getUrlPath(reflection, {
                ...options,
                directory,
            });
            let url = getUrl(reflection, urlPath);
            const duplicateUrls = urls.filter((urlMapping) => urlMapping.url.toLowerCase().replace(/-\d+$/, '') ===
                url.toLowerCase());
            if (duplicateUrls.length > 0) {
                const urlParts = url.split('.');
                urlParts[urlParts.length - 2] += `-${duplicateUrls.length}`;
                url = urlParts.join('.');
            }
            urls.push({
                url: url,
                model: reflection,
                template: mapping.template,
            });
            reflection.url = url;
            reflection.hasOwnDocument = true;
            reflection.groups?.forEach((group) => {
                group.children.forEach((groupChild) => {
                    const mapping = theme.getTemplateMapping(groupChild.kind, options.outputFileStrategy);
                    buildUrlsFromGroup(groupChild, {
                        parentUrl: urlPath,
                        directory: mapping?.directory || null,
                        outputFileStrategy: options.outputFileStrategy,
                    });
                });
            });
        }
        else if (reflection.parent) {
            applyAnchorUrl(reflection, reflection.parent);
        }
    }
    function getUrl(reflection, urlPath) {
        if (reflection.name === options.getValue('entryModule')) {
            return options.getValue('entryFileName');
        }
        if (options.getValue('outputFileStrategy') === option_maps_1.OutputFileStrategy.Modules &&
            reflection.name === 'index') {
            return urlPath.replace('index.md', 'module.index.md');
        }
        return urlPath;
    }
    function getUrlPath(reflection, urlOption) {
        const alias = reflection.name
            .replace(/^_+/, '')
            .replace(/</, '-')
            .replace(/>/, '-');
        const parentDir = urlOption.parentUrl
            ? path.dirname(urlOption.parentUrl)
            : null;
        const dir = () => {
            if (reflection.kind === typedoc_1.ReflectionKind.Namespace) {
                return `${urlOption.directory}/${alias}`;
            }
            if (reflection.kind === typedoc_1.ReflectionKind.Module) {
                return alias;
            }
            const slugifyUrl = (url) => {
                return url
                    .toLowerCase()
                    .trim()
                    .replace(/[^\w\s-]/g, '')
                    .replace(/[\s_-]+/g, '-')
                    .replace(/^-+|-+$/g, '');
            };
            return urlOption.directory
                ? urlOption.directory
                : `${slugifyUrl(typedoc_1.ReflectionKind.singularString(reflection.kind))}.${alias}`;
        };
        const filename = () => {
            if ([typedoc_1.ReflectionKind.Module, typedoc_1.ReflectionKind.Namespace].includes(reflection.kind) &&
                options.getValue('outputFileStrategy') === option_maps_1.OutputFileStrategy.Modules &&
                !childrenIncludeNamespaces(reflection)) {
                return null;
            }
            if ([typedoc_1.ReflectionKind.Module, typedoc_1.ReflectionKind.Namespace].includes(reflection.kind)) {
                return path.parse(options.getValue('entryFileName')).name;
            }
            return alias;
        };
        return ([parentDir, dir(), filename()].filter((part) => Boolean(part)).join('/') +
            '.md');
    }
    function applyAnchorUrl(reflection, container) {
        if (container.url) {
            if (!reflection.kindOf(typedoc_1.ReflectionKind.TypeLiteral)) {
                const anchorPrefix = options.getValue('anchorPrefix');
                const anchorId = getAnchorId(reflection);
                if (anchorId) {
                    if (!anchors[container.url]) {
                        anchors[container.url] = [];
                    }
                    anchors[container.url].push(anchorId);
                    const count = anchors[container.url]?.filter((id) => id === anchorId)?.length;
                    const anchorParts = [anchorId];
                    if (count > 1) {
                        anchorParts.push(`-${count - 1}`);
                    }
                    if (anchorPrefix) {
                        anchorParts.unshift(`${anchorPrefix}`);
                    }
                    reflection.url = container.url + '#' + anchorParts.join('');
                    reflection.anchor = anchorParts.join('');
                }
            }
            reflection.hasOwnDocument = false;
        }
        if (reflection.parent) {
            reflection.traverse((child) => {
                if (child instanceof typedoc_1.DeclarationReflection) {
                    applyAnchorUrl(child, container);
                }
            });
        }
    }
    function getAnchorId(reflection) {
        const preserveAnchorCasing = options.getValue('preserveAnchorCasing');
        const anchorName = getAnchorName(reflection);
        if (anchorName) {
            return preserveAnchorCasing ? anchorName : anchorName.toLowerCase();
        }
        return null;
    }
    function getAnchorName(reflection) {
        const htmlTableAnchors = options.getValue('namedAnchors');
        if (!htmlTableAnchors) {
            if ((reflection.kindOf(typedoc_1.ReflectionKind.Property) &&
                options.getValue('propertiesFormat') === 'table') ||
                (reflection.kindOf(typedoc_1.ReflectionKind.EnumMember) &&
                    options.getValue('enumMembersFormat') === 'table')) {
                return null;
            }
        }
        if (reflection.kindOf(typedoc_1.ReflectionKind.Constructor)) {
            return 'Constructors';
        }
        const anchorParts = [reflection.name];
        if (reflection.typeParameters?.length) {
            anchorParts.push(reflection.typeParameters
                .map((typeParameter) => typeParameter.name)
                .join(''));
        }
        return anchorParts.join('');
    }
    function childrenIncludeNamespaces(reflection) {
        return reflection.children?.some((child) => child.kind === typedoc_1.ReflectionKind.Namespace);
    }
    function getIndexFileName(reflection, isPackages = false) {
        if (isPackages) {
            return 'packages.md';
        }
        const isModules = reflection.children?.every((child) => child.kindOf(typedoc_1.ReflectionKind.Module));
        return isModules ? 'modules.md' : 'globals.md';
    }
}
exports.getUrls = getUrls;
