import { MarkdownThemeRenderContext } from '../..';
import { flattenDeclarations, getDeclarationType, getIndexTitle, getKeyword, getModifier, getParameterDefaultValue, isGroupKind } from './helpers';
export declare const templates: (context: MarkdownThemeRenderContext) => {
    memberTemplate: (page: import("../..").MarkdownPageEvent<import("typedoc").DeclarationReflection>) => string;
    projectTemplate: (page: import("../..").MarkdownPageEvent<import("typedoc").ProjectReflection>) => string;
    readmeTemplate: (page: import("../..").MarkdownPageEvent<import("typedoc").ProjectReflection>) => string;
    reflectionTemplate: (page: import("../..").MarkdownPageEvent<import("typedoc").DeclarationReflection>) => string;
};
export declare const partials: (context: MarkdownThemeRenderContext) => {
    breadcrumbs: (page: import("../..").MarkdownPageEvent<import("typedoc").DeclarationReflection | import("typedoc").ProjectReflection>) => string;
    commentParts: (parts: import("typedoc").CommentDisplayPart[]) => string;
    comment: (comment: import("typedoc").Comment, headingLevel?: number | undefined, showSummary?: boolean | undefined, showTags?: boolean | undefined) => string;
    header: (page: import("../..").MarkdownPageEvent<import("typedoc").DeclarationReflection | import("typedoc").ProjectReflection>) => string;
    pageIndex: (page: import("../..").MarkdownPageEvent<import("typedoc").DeclarationReflection | import("typedoc").ProjectReflection>, headingLevel: number) => string;
    reflectionIndex: (reflection: import("typedoc").DeclarationReflection | import("typedoc").ProjectReflection, headingLevel: number) => string;
    linkTo: (label: string, url?: string | undefined) => string;
    parametersList: (parameters: import("typedoc").ParameterReflection[]) => string;
    typeParametersList: (typeParameters: import("typedoc").TypeParameterReflection[]) => string;
    accessorMember: (declaration: import("typedoc").DeclarationReflection, headingLevel: number) => string;
    constructorMember: (reflection: import("typedoc").DeclarationReflection, headingLevel: number) => string;
    declarationMemberIdentifier: (reflection: import("typedoc").DeclarationReflection) => string;
    declarationMember: (declaration: import("typedoc").DeclarationReflection, headingLevel: number, nested?: boolean | undefined) => string;
    memberHierarchy: (declarationHierarchy: import("typedoc").DeclarationHierarchy, headingLevel: number) => string;
    indexSignatureTitle: (signature: import("typedoc").SignatureReflection) => string;
    inheritance: (reflection: import("typedoc").DeclarationReflection | import("typedoc").SignatureReflection, headingLevel: number) => string;
    referenceMember: (props: import("typedoc").ReferenceReflection) => string;
    reflectionMember: (reflection: import("typedoc").DeclarationReflection, headingLevel: number) => string;
    signatureMemberIdentifier: (signature: import("typedoc").SignatureReflection, opts?: {
        accessor?: string | undefined;
        includeType?: boolean | undefined;
    } | undefined) => string;
    signatureParameters: (parameters: import("typedoc").ParameterReflection[], format?: boolean | undefined) => string;
    signatureMemberReturns: (signature: import("typedoc").SignatureReflection, headingLevel: number) => string;
    signatureMember: (signature: import("typedoc").SignatureReflection, headingLevel: number, nested?: boolean | undefined, accessor?: string | undefined) => string;
    sources: (reflection: import("typedoc").DeclarationReflection | import("typedoc").SignatureReflection, headingLevel: number) => string;
    memberTitle: (reflection: import("typedoc").DeclarationReflection) => string;
    member: (reflection: import("typedoc").DeclarationReflection, headingLevel: number, nested?: boolean | undefined) => string;
    typeDeclarationMember: (typeDeclaration: import("typedoc").DeclarationReflection, headingLevel: number) => string;
    members: (container: import("typedoc").ContainerReflection, headingLevel: number) => string;
    pageTitle: (page: import("../..").MarkdownPageEvent<import("typedoc").DeclarationReflection | import("typedoc").ProjectReflection>) => string;
    reflectionFlags: (reflection: import("typedoc").Reflection) => string;
    enumMembersTable: (props: import("typedoc").DeclarationReflection[]) => string;
    parametersTable: (parameters: import("typedoc").ParameterReflection[]) => string;
    propertiesTable: (props: import("typedoc").DeclarationReflection[], isEventProps?: boolean | undefined) => string;
    typeDeclarationTable: (props: import("typedoc").DeclarationReflection[]) => string;
    typeParametersTable: (typeParameters: import("typedoc").TypeParameterReflection[]) => string;
    typeArguments: (typeArguments: import("typedoc").SomeType[], foreCollpase?: boolean | undefined) => string;
    arrayType: (arrayType: import("typedoc").ArrayType) => string;
    conditionalType: (conditionalType: import("typedoc").ConditionalType) => string;
    declarationType: (declarationReflection: import("typedoc").DeclarationReflection) => string;
    functionType: (signatures: import("typedoc").SignatureReflection[], forceParameterType?: boolean | undefined) => string;
    indexAccessType: (model: import("typedoc").IndexedAccessType) => string;
    inferredType: (model: import("typedoc").InferredType) => string;
    intersectionType: (model: import("typedoc").IntersectionType) => string;
    intrinsicType: (model: import("typedoc").IntrinsicType) => string;
    literalType: (literalType: import("typedoc").LiteralType) => string;
    namedTupleType: (member: import("typedoc").NamedTupleMember) => string;
    queryType: (queryType: import("typedoc").QueryType) => string;
    referenceType: (referenceType: import("typedoc").ReferenceType, foreCollpase?: boolean | undefined) => string;
    reflectionType: (reflectionType: import("typedoc").ReflectionType, foreCollpase?: boolean | undefined) => string;
    someType: (someType: import("typedoc").SomeType, foreCollpase?: boolean | undefined) => string;
    tupleType: (tupleType: import("typedoc").TupleType) => string;
    typeOperatorType: (model: import("typedoc").TypeOperatorType) => string;
    unionType: (unionType: import("typedoc").UnionType) => string;
    unknownType: (model: import("typedoc").UnknownType) => string;
};
export declare const helpers: () => {
    flattenDeclarations: typeof flattenDeclarations;
    getDeclarationType: typeof getDeclarationType;
    getIndexTitle: typeof getIndexTitle;
    getKeyword: typeof getKeyword;
    getModifier: typeof getModifier;
    getParameterDefaultValue: typeof getParameterDefaultValue;
    isGroupKind: typeof isGroupKind;
};
