"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.helpers = exports.partials = exports.templates = void 0;
const templates_1 = require("./templates");
const partials_1 = require("./partials");
const helpers_1 = require("./helpers");
function bind(fn, first) {
    return (...args) => fn(first, ...args);
}
const templates = (context) => {
    return {
        memberTemplate: bind(templates_1.memberTemplate, context),
        projectTemplate: bind(templates_1.projectTemplate, context),
        readmeTemplate: bind(templates_1.readmeTemplate, context),
        reflectionTemplate: bind(templates_1.reflectionTemplate, context),
    };
};
exports.templates = templates;
const partials = (context) => {
    return {
        breadcrumbs: bind(partials_1.breadcrumbs, context),
        commentParts: bind(partials_1.commentParts, context),
        comment: bind(partials_1.comment, context),
        header: bind(partials_1.header, context),
        pageIndex: bind(partials_1.pageIndex, context),
        reflectionIndex: bind(partials_1.reflectionIndex, context),
        linkTo: bind(partials_1.linkTo, context),
        parametersList: bind(partials_1.parametersList, context),
        typeParametersList: bind(partials_1.typeParametersList, context),
        accessorMember: bind(partials_1.accessorMember, context),
        constructorMember: bind(partials_1.constructorMember, context),
        declarationMemberIdentifier: bind(partials_1.declarationMemberIdentifier, context),
        declarationMember: bind(partials_1.declarationMember, context),
        memberHierarchy: bind(partials_1.memberHierarchy, context),
        indexSignatureTitle: bind(partials_1.indexSignatureTitle, context),
        inheritance: bind(partials_1.inheritance, context),
        referenceMember: bind(partials_1.referenceMember, context),
        reflectionMember: bind(partials_1.reflectionMember, context),
        signatureMemberIdentifier: bind(partials_1.signatureMemberIdentifier, context),
        signatureParameters: bind(partials_1.signatureParameters, context),
        signatureMemberReturns: bind(partials_1.signatureMemberReturns, context),
        signatureMember: bind(partials_1.signatureMember, context),
        sources: bind(partials_1.sources, context),
        memberTitle: bind(partials_1.memberTitle, context),
        member: bind(partials_1.member, context),
        typeDeclarationMember: bind(partials_1.typeDeclarationMember, context),
        members: bind(partials_1.members, context),
        pageTitle: bind(partials_1.pageTitle, context),
        reflectionFlags: bind(partials_1.reflectionFlags, context),
        enumMembersTable: bind(partials_1.enumMembersTable, context),
        parametersTable: bind(partials_1.parametersTable, context),
        propertiesTable: bind(partials_1.propertiesTable, context),
        typeDeclarationTable: bind(partials_1.typeDeclarationTable, context),
        typeParametersTable: bind(partials_1.typeParametersTable, context),
        typeArguments: bind(partials_1.typeArguments, context),
        arrayType: bind(partials_1.arrayType, context),
        conditionalType: bind(partials_1.conditionalType, context),
        declarationType: bind(partials_1.declarationType, context),
        functionType: bind(partials_1.functionType, context),
        indexAccessType: bind(partials_1.indexAccessType, context),
        inferredType: bind(partials_1.inferredType, context),
        intersectionType: bind(partials_1.intersectionType, context),
        intrinsicType: bind(partials_1.intrinsicType, context),
        literalType: bind(partials_1.literalType, context),
        namedTupleType: bind(partials_1.namedTupleType, context),
        queryType: bind(partials_1.queryType, context),
        referenceType: bind(partials_1.referenceType, context),
        reflectionType: bind(partials_1.reflectionType, context),
        someType: bind(partials_1.someType, context),
        tupleType: bind(partials_1.tupleType, context),
        typeOperatorType: bind(partials_1.typeOperatorType, context),
        unionType: bind(partials_1.unionType, context),
        unknownType: bind(partials_1.unknownType, context),
    };
};
exports.partials = partials;
const helpers = () => {
    return {
        flattenDeclarations: helpers_1.flattenDeclarations,
        getDeclarationType: helpers_1.getDeclarationType,
        getIndexTitle: helpers_1.getIndexTitle,
        getKeyword: helpers_1.getKeyword,
        getModifier: helpers_1.getModifier,
        getParameterDefaultValue: helpers_1.getParameterDefaultValue,
        isGroupKind: helpers_1.isGroupKind,
    };
};
exports.helpers = helpers;
