"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.isFile = exports.commentParts = void 0;
const fs = __importStar(require("fs"));
const utils_1 = require("../utils");
function commentParts(context, parts) {
    const md = [];
    const parsedText = (text) => {
        const mediaPattern = /media:\/\/([^ ")\]}]+)/g;
        const includePattern = /\[\[include:([^\]]+?)\]\]/g;
        const includeDirectory = context.options.getValue('includes');
        const mediaDirectory = context.options.getValue('media');
        let parsedText = text;
        if (Boolean(includeDirectory)) {
            parsedText = parsedText.replace(includePattern, (match, includeFile) => {
                const includeDirectory = context.options.getValue('includes');
                const includesPath = (0, utils_1.getRelativeUrl)(`${includeDirectory}/${includeFile}`, context.page?.url);
                if (isFile(includesPath)) {
                    const includeContent = fs.readFileSync(includesPath);
                    return includeContent.toString();
                }
                else {
                    return match;
                }
            });
        }
        if (Boolean(mediaDirectory)) {
            parsedText = parsedText.replace(mediaPattern, (match, mediaFile) => {
                return (0, utils_1.getRelativeUrl)(`media/${mediaFile}`, context.page?.url);
            });
        }
        return parsedText;
    };
    for (const part of parts) {
        switch (part.kind) {
            case 'text':
                md.push(parsedText(part.text));
                break;
            case 'code':
                md.push(part.text);
                break;
            case 'inline-tag':
                switch (part.tag) {
                    case '@label':
                    case '@inheritdoc':
                        break;
                    case '@link':
                    case '@linkcode':
                    case '@linkplain': {
                        if (part.target) {
                            const url = getUrl(part);
                            const wrap = part.tag === '@linkcode' ? '`' : '';
                            md.push(url
                                ? `${context.partials.linkTo(`${wrap}${part.text}${wrap}`, url)}`
                                : part.text);
                        }
                        else {
                            md.push(part.text);
                        }
                        break;
                    }
                    default:
                        md.push(`{${part.tag} ${part.text}}`);
                        break;
                }
                break;
            default:
                md.push('');
        }
    }
    return md.join('');
}
exports.commentParts = commentParts;
function getUrl(part) {
    if (part.target.url) {
        return part.target.url;
    }
    if (part.target?.parent?.url) {
        return part.target?.parent?.url;
    }
    return part.target;
}
function isFile(file) {
    try {
        return fs.statSync(file).isFile();
    }
    catch {
        return false;
    }
}
exports.isFile = isFile;
