"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.reflectionIndex = void 0;
const typedoc_1 = require("typedoc");
const markdown_1 = require("../markdown");
const utils_1 = require("../utils");
function reflectionIndex(context, reflection, headingLevel) {
    const md = [];
    const subHeadingLevel = headingLevel;
    if (reflection.categories) {
        reflection.categories.forEach((categoryGroup) => {
            md.push((0, markdown_1.heading)(subHeadingLevel, categoryGroup.title) + '\n');
            md.push(getGroup(context, categoryGroup) + '\n');
        });
    }
    else {
        const groups = reflection.groups?.filter((group) => group.allChildrenHaveOwnDocument());
        groups?.forEach((reflectionGroup) => {
            if (reflectionGroup.categories) {
                md.push((0, markdown_1.heading)(subHeadingLevel, reflectionGroup.title) + '\n');
                reflectionGroup.categories.forEach((categoryGroup) => {
                    md.push((0, markdown_1.heading)(subHeadingLevel + 1, categoryGroup.title) + '\n');
                    md.push(getGroup(context, categoryGroup) + '\n');
                });
            }
            else {
                md.push((0, markdown_1.heading)(subHeadingLevel, context.getTextFromKindString(reflectionGroup.title, true)) + '\n');
                md.push(getGroup(context, reflectionGroup) + '\n');
            }
        });
    }
    return md.join('\n');
}
exports.reflectionIndex = reflectionIndex;
function getGroup(context, group) {
    if (context.options.getValue('indexFormat') === 'table') {
        return getTable(context, group);
    }
    return getList(context, group);
}
function getTable(context, group) {
    const reflectionKind = group.children[0].kind;
    const headers = [
        typedoc_1.ReflectionKind.singularString(reflectionKind),
        context.getText('label.description'),
    ];
    const rows = [];
    group.children.forEach((child) => {
        const row = [];
        row.push(context.partials.linkTo((0, utils_1.escapeChars)(child.name), child.url));
        const comment = getComment(child);
        if (comment?.summary?.length) {
            row.push((0, utils_1.formatTableDescriptionCol)(context.partials.commentParts(comment.summary)).split('\n')[0]);
        }
        else {
            row.push('-');
        }
        rows.push(row);
    });
    return (0, markdown_1.table)(headers, rows);
}
function getList(context, group) {
    const children = group.children
        .filter((child) => Boolean(child.url))
        .map((child) => {
        const name = child.name === 'constructor'
            ? `${child.signatures
                ? child.signatures[0].name
                : context.getText('kind.constructor.singular')}`
            : child.name;
        return `- ${context.partials.linkTo((0, utils_1.escapeChars)(name), child.url)}`;
    });
    return children.join('\n');
}
function getComment(declaration) {
    if (declaration.signatures?.length) {
        return declaration.signatures[0].comment;
    }
    if (declaration.type?.declaration?.signatures?.length) {
        return declaration.type?.declaration.signatures[0].comment;
    }
    return declaration.comment;
}
