"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.accessorMember = void 0;
const typedoc_1 = require("typedoc");
const markdown_1 = require("../markdown");
function accessorMember(context, declaration, headingLevel) {
    const md = [];
    if (declaration.getSignature) {
        md.push(context.partials.signatureMemberIdentifier(declaration.getSignature, {
            accessor: 'get',
        }));
        if (declaration.getSignature.comment) {
            md.push(context.partials.comment(declaration.getSignature.comment, headingLevel));
        }
    }
    if (declaration.setSignature) {
        md.push(context.partials.signatureMemberIdentifier(declaration.setSignature, {
            accessor: 'set',
        }));
        if (declaration.setSignature.comment) {
            md.push(context.partials.comment(declaration.setSignature.comment, headingLevel));
        }
    }
    if (declaration.setSignature?.parameters?.length) {
        md.push((0, markdown_1.heading)(headingLevel, context.getText('kind.parameter.plural')));
        if (context.options.getValue('parametersFormat') === 'table') {
            md.push(context.partials.parametersTable(declaration.setSignature.parameters));
        }
        else {
            md.push(context.partials.parametersList(declaration.setSignature.parameters));
        }
    }
    if (declaration.getSignature?.type) {
        md.push(context.partials.signatureMemberReturns(declaration.getSignature, headingLevel));
    }
    const showSources = !declaration?.parent?.kindOf(typedoc_1.ReflectionKind.TypeLiteral);
    if (showSources && !context.options.getValue('disableSources')) {
        if (declaration.getSignature?.sources) {
            md.push(context.partials.sources(declaration.getSignature, headingLevel));
        }
        else if (declaration.setSignature?.sources) {
            md.push(context.partials.sources(declaration.setSignature, headingLevel));
        }
    }
    return md.join('\n\n');
}
exports.accessorMember = accessorMember;
