"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.declarationMember = void 0;
const typedoc_1 = require("typedoc");
const markdown_1 = require("../markdown");
function declarationMember(context, declaration, headingLevel, nested = false) {
    const md = [];
    md.push(context.partials.reflectionFlags(declaration));
    md.push(context.partials.declarationMemberIdentifier(declaration));
    const typeDeclaration = declaration.type
        ?.declaration;
    if (!typeDeclaration?.signatures?.every((signature) => Boolean(signature.comment))) {
        if (declaration.comment) {
            md.push(context.partials.comment(declaration.comment, headingLevel));
        }
    }
    if (declaration.type instanceof typedoc_1.IntersectionType) {
        declaration.type?.types?.forEach((intersectionType) => {
            if (intersectionType instanceof typedoc_1.ReflectionType &&
                !intersectionType.declaration.signatures) {
                md.push((0, markdown_1.heading)(headingLevel, context.getText('label.typeDeclaration')));
                md.push(context.partials.typeDeclarationMember(intersectionType.declaration, headingLevel));
            }
        });
    }
    if (declaration.type instanceof typedoc_1.ReferenceType &&
        declaration.type.typeArguments?.length) {
        if (declaration.type.typeArguments[0] instanceof typedoc_1.ReflectionType) {
            md.push((0, markdown_1.heading)(headingLevel, context.getText('label.typeDeclaration')));
            md.push(context.partials.typeDeclarationMember(declaration.type.typeArguments[0].declaration, headingLevel));
        }
    }
    if (declaration.typeParameters) {
        md.push((0, markdown_1.heading)(headingLevel, context.getText('kind.typeParameter.plural')));
        if (context.options.getValue('parametersFormat') === 'table') {
            md.push(context.partials.typeParametersTable(declaration.typeParameters));
        }
        else {
            md.push(context.partials.typeParametersList(declaration.typeParameters));
        }
    }
    if (typeDeclaration) {
        if (typeDeclaration?.indexSignature) {
            md.push((0, markdown_1.heading)(headingLevel, context.getText('label.indexSignature')));
            md.push(context.partials.indexSignatureTitle(typeDeclaration.indexSignature));
        }
        if (typeDeclaration?.signatures?.length) {
            typeDeclaration.signatures.forEach((signature) => {
                md.push(context.partials.signatureMember(signature, headingLevel, true));
            });
        }
        if (typeDeclaration?.children?.length) {
            if (!nested && typeDeclaration?.children?.length) {
                md.push((0, markdown_1.heading)(headingLevel, context.getText('label.typeDeclaration')));
                md.push(context.partials.typeDeclarationMember(typeDeclaration, headingLevel));
            }
        }
    }
    md.push(context.partials.inheritance(declaration, headingLevel));
    if (!nested &&
        declaration.sources &&
        !context.options.getValue('disableSources')) {
        md.push(context.partials.sources(declaration, headingLevel));
    }
    return md.join('\n\n');
}
exports.declarationMember = declarationMember;
