"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.inheritance = void 0;
const typedoc_1 = require("typedoc");
const markdown_1 = require("../markdown");
function inheritance(context, reflection, headingLevel) {
    const md = [];
    if (reflection.implementationOf) {
        if (headingLevel !== -1) {
            md.push((0, markdown_1.heading)(headingLevel, context.getText('label.implementationOf')));
        }
        md.push(typeAndParent(context, reflection.implementationOf));
    }
    if (reflection.inheritedFrom) {
        if (headingLevel !== -1) {
            md.push((0, markdown_1.heading)(headingLevel, context.getText('label.inheritedFrom')));
        }
        md.push(typeAndParent(context, reflection.inheritedFrom));
    }
    if (reflection.overwrites) {
        const overridesLabel = context.getText('label.overrides');
        if (headingLevel !== -1) {
            md.push((0, markdown_1.heading)(headingLevel, overridesLabel));
        }
        md.push(typeAndParent(context, reflection.overwrites));
    }
    return md.join('\n\n');
}
exports.inheritance = inheritance;
const typeAndParent = (context, props) => {
    if (!props) {
        return (0, markdown_1.backTicks)('void');
    }
    if (props instanceof typedoc_1.ArrayType) {
        return `${typeAndParent(context, props.elementType)}[]`;
    }
    if (props instanceof typedoc_1.ReferenceType && props.reflection) {
        const refl = props.reflection instanceof typedoc_1.SignatureReflection
            ? props.reflection.parent
            : props.reflection;
        const parent = refl?.parent;
        if (parent) {
            const resultWithParent = [];
            if (parent?.url) {
                resultWithParent.push(context.partials.linkTo((0, markdown_1.backTicks)(parent.name), parent.url));
            }
            else {
                resultWithParent.push((0, markdown_1.backTicks)(parent?.name));
            }
            if (refl?.url) {
                resultWithParent.push(context.partials.linkTo((0, markdown_1.backTicks)(refl.name), refl.url));
            }
            else {
                resultWithParent.push((0, markdown_1.backTicks)(refl?.name));
            }
            return resultWithParent.join('.');
        }
    }
    return (0, markdown_1.backTicks)(props.toString());
};
