"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.member = void 0;
const typedoc_1 = require("typedoc");
const markdown_1 = require("../markdown");
const utils_1 = require("../utils");
function member(context, reflection, headingLevel, nested = false) {
    const md = [];
    if (context.options.getValue('namedAnchors')) {
        md.push(`<a id="${reflection.anchor}" name="${reflection.anchor}"></a>`);
    }
    if (!reflection.hasOwnDocument &&
        !(reflection.kind === typedoc_1.ReflectionKind.Constructor)) {
        const memberName = context.partials.memberTitle(reflection);
        md.push((0, markdown_1.heading)(headingLevel, memberName));
    }
    const getMember = (reflection) => {
        if ([
            typedoc_1.ReflectionKind.Class,
            typedoc_1.ReflectionKind.Interface,
            typedoc_1.ReflectionKind.Enum,
        ].includes(reflection.kind)) {
            return context.partials.reflectionMember(reflection, headingLevel + 1);
        }
        if (reflection.kind === typedoc_1.ReflectionKind.Constructor) {
            return context.partials.constructorMember(reflection, headingLevel);
        }
        if (reflection.kind === typedoc_1.ReflectionKind.Accessor) {
            return context.partials.accessorMember(reflection, headingLevel + 1);
        }
        if (reflection.signatures) {
            return reflection.signatures
                ?.map((signature) => {
                const signatureMd = [];
                const multipleSignatures = reflection.signatures && reflection.signatures?.length > 1;
                if (multipleSignatures) {
                    signatureMd.push((0, markdown_1.heading)(headingLevel + 1, `${(0, utils_1.escapeChars)(signature.name)}(${signature.parameters
                        ?.map((param) => param.name)
                        .join(', ')})`));
                }
                signatureMd.push(context.partials.signatureMember(signature, multipleSignatures ? headingLevel + 2 : headingLevel + 1, nested));
                return signatureMd.join('\n\n');
            })
                .join('\n\n');
        }
        if (reflection instanceof typedoc_1.ReferenceReflection) {
            return context.partials.referenceMember(reflection);
        }
        return context.partials.declarationMember(reflection, headingLevel + 1, nested);
    };
    const member = getMember(reflection);
    if (member) {
        md.push(member);
    }
    return md.join('\n\n');
}
exports.member = member;
