"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.reflectionMember = void 0;
const markdown_1 = require("../markdown");
function reflectionMember(context, reflection, headingLevel) {
    const md = [];
    if (reflection.comment) {
        md.push(context.partials.comment(reflection.comment, headingLevel));
    }
    if (reflection.typeHierarchy?.next) {
        md.push(context.partials.memberHierarchy(reflection.typeHierarchy, headingLevel));
    }
    if (reflection.typeParameters) {
        md.push((0, markdown_1.heading)(headingLevel, context.getText('kind.typeParameter.plural')));
        if (context.options.getValue('parametersFormat') === 'table') {
            md.push(context.partials.typeParametersTable(reflection.typeParameters));
        }
        else {
            md.push(context.partials.typeParametersList(reflection.typeParameters));
        }
    }
    if (reflection.implementedTypes) {
        md.push((0, markdown_1.heading)(headingLevel, context.getText('label.implements')));
        md.push((0, markdown_1.unorderedList)(reflection.implementedTypes.map((implementedType) => context.partials.someType(implementedType))));
    }
    if ('signatures' in reflection && reflection.signatures) {
        reflection.signatures.forEach((signature) => {
            md.push(context.partials.signatureMember(signature, headingLevel));
        });
    }
    if ('indexSignature' in reflection && reflection.indexSignature) {
        md.push((0, markdown_1.heading)(headingLevel, context.getText('label.indexable')));
        md.push(context.partials.indexSignatureTitle(reflection.indexSignature));
    }
    if (reflection?.groups?.some((group) => group.allChildrenHaveOwnDocument())) {
        const isAbsolute = reflection.groups?.every((group) => group.allChildrenHaveOwnDocument());
        if (isAbsolute) {
            md.push((0, markdown_1.heading)(headingLevel, context.getText('label.index')));
        }
        md.push(context.partials.reflectionIndex(reflection, isAbsolute ? headingLevel + 1 : headingLevel));
    }
    md.push(context.partials.members(reflection, headingLevel));
    return md.join('\n\n');
}
exports.reflectionMember = reflectionMember;
