"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.signatureMemberIdentifier = void 0;
const markdown_1 = require("../markdown");
const utils_1 = require("../utils");
function signatureMemberIdentifier(context, signature, opts) {
    const md = [];
    const DEFAULT_OPTIONS = {
        accessor: null,
        useCodeBlocks: false,
    };
    const options = { ...DEFAULT_OPTIONS, ...opts };
    const useCodeBlocks = context.options.getValue('useCodeBlocks');
    const keyword = context.helpers.getKeyword(signature.parent.kind);
    if (useCodeBlocks &&
        context.helpers.isGroupKind(signature.parent) &&
        keyword) {
        md.push(keyword + ' ');
    }
    if (options?.accessor) {
        md.push((0, markdown_1.bold)((0, markdown_1.backTicks)(options?.accessor)) + ' ');
    }
    if (signature.parent && signature.parent.flags?.length > 0) {
        md.push(signature.parent.flags
            .map((flag) => (0, markdown_1.bold)((0, markdown_1.backTicks)(flag.toLowerCase())))
            .join(' ') + ' ');
    }
    if (!['__call', '__type'].includes(signature.name)) {
        md.push((0, markdown_1.bold)((0, utils_1.escapeChars)(signature.name)));
    }
    if (signature.typeParameters) {
        md.push(`\\<${signature.typeParameters
            .map((typeParameter) => (0, markdown_1.backTicks)(typeParameter.name))
            .join(', ')}\\>`);
    }
    md.push(context.partials.signatureParameters(signature.parameters || [], useCodeBlocks));
    if (signature.type) {
        md.push(`: ${context.partials.someType(signature.type)}`);
    }
    const result = md.join('');
    return useCodeBlocks ? (0, markdown_1.codeBlock)(result) : `> ${result}`;
}
exports.signatureMemberIdentifier = signatureMemberIdentifier;
