"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.signatureMemberReturns = void 0;
const typedoc_1 = require("typedoc");
const markdown_1 = require("../markdown");
function signatureMemberReturns(context, signature, headingLevel) {
    const md = [];
    const typeDeclaration = signature.type
        ?.declaration;
    md.push((0, markdown_1.heading)(headingLevel, context.getText('label.returns')));
    md.push(getReturnType(context, typeDeclaration, signature.type));
    if (signature.comment?.blockTags.length) {
        const tags = signature.comment.blockTags
            .filter((tag) => tag.tag === '@returns')
            .map((tag) => context.partials.commentParts(tag.content));
        md.push(tags.join('\n\n'));
    }
    if (signature.type instanceof typedoc_1.ReferenceType &&
        signature.type.typeArguments?.length) {
        if (signature.type.typeArguments[0] instanceof typedoc_1.ReflectionType) {
            md.push((0, markdown_1.blockQuoteBlock)(context.partials.typeDeclarationMember(signature.type.typeArguments[0].declaration, headingLevel)));
        }
    }
    if (typeDeclaration?.signatures) {
        typeDeclaration.signatures.forEach((signature) => {
            md.push((0, markdown_1.blockQuoteBlock)(context.partials.signatureMember(signature, headingLevel + 1, true)));
        });
    }
    if (typeDeclaration?.children) {
        md.push((0, markdown_1.blockQuoteBlock)(context.partials.typeDeclarationMember(typeDeclaration, headingLevel)));
    }
    return md.join('\n\n');
}
exports.signatureMemberReturns = signatureMemberReturns;
function getReturnType(context, typeDeclaration, type) {
    if (typeDeclaration?.children) {
        return (0, markdown_1.backTicks)('Object');
    }
    if (typeDeclaration?.signatures) {
        return (0, markdown_1.backTicks)('Function');
    }
    return type ? context.partials.someType(type, true).replace(/\n/g, ' ') : '';
}
