"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.memberTitle = void 0;
const typedoc_1 = require("typedoc");
const markdown_1 = require("../markdown");
const utils_1 = require("../utils");
function memberTitle(context, reflection) {
    const md = [];
    const name = [];
    if (reflection?.kind === typedoc_1.ReflectionKind.Class &&
        reflection.flags?.includes('Abstract')) {
        name.push((0, markdown_1.backTicks)('abstract') + ' ');
    }
    name.push(`${reflection.name.startsWith('[') && reflection.signatures?.length
        ? (0, markdown_1.backTicks)(reflection.name)
        : (0, utils_1.escapeChars)(reflection.name)}`);
    if (reflection.signatures?.length) {
        name.push('()');
    }
    if (reflection.typeParameters) {
        const typeParameters = reflection.typeParameters
            .map((typeParameter) => typeParameter.name)
            .join(', ');
        name.push(`${`\\<${typeParameters}\\>`}`);
    }
    if (reflection.flags.isOptional) {
        name.push('?');
    }
    if (reflection.isDeprecated && reflection.isDeprecated()) {
        md.push((0, markdown_1.strikeThrough)(name.join('')));
    }
    else {
        md.push(name.join(''));
    }
    return md.join(': ');
}
exports.memberTitle = memberTitle;
