"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.members = void 0;
const typedoc_1 = require("typedoc");
const markdown_1 = require("../markdown");
function members(context, container, headingLevel) {
    const md = [];
    const displayHr = (reflection) => {
        if (context.options.getValue('outputFileStrategy') === 'modules') {
            return context.helpers.isGroupKind(reflection);
        }
        return true;
    };
    const pushCategories = (categories, headingLevel) => {
        categories
            ?.filter((category) => !category.allChildrenHaveOwnDocument())
            .forEach((item) => {
            md.push((0, markdown_1.heading)(headingLevel, item.title));
            pushChildren(item.children, headingLevel + 1);
        });
    };
    const pushChildren = (children, memberHeadingLevel) => {
        const items = children?.filter((item) => !item.hasOwnDocument);
        items?.forEach((item, index) => {
            md.push(context.partials.member(item, memberHeadingLevel || headingLevel));
            if (index < items.length - 1 && displayHr(item)) {
                md.push((0, markdown_1.horizontalRule)());
            }
        });
    };
    if (container.categories?.length) {
        pushCategories(container.categories, headingLevel);
    }
    else {
        if (context.options.getValue('excludeGroups') &&
            container.kindOf([
                typedoc_1.ReflectionKind.Project,
                typedoc_1.ReflectionKind.Module,
                typedoc_1.ReflectionKind.Namespace,
            ])) {
            if (container.categories?.length) {
                pushCategories(container.categories, headingLevel);
            }
            else {
                pushChildren(container.children, headingLevel);
            }
        }
        else {
            const groupsWithChildren = container.groups?.filter((group) => !group.allChildrenHaveOwnDocument());
            groupsWithChildren?.forEach((group, index) => {
                if (group.categories) {
                    md.push((0, markdown_1.heading)(headingLevel, context.getTextFromKindString(group.title, true)));
                    pushCategories(group.categories, headingLevel + 1);
                }
                else {
                    const isPropertiesGroup = group.children.every((child) => child.kindOf(typedoc_1.ReflectionKind.Property));
                    const isEnumGroup = group.children.every((child) => child.kindOf(typedoc_1.ReflectionKind.EnumMember));
                    md.push((0, markdown_1.heading)(headingLevel, context.getTextFromKindString(group.title, true)));
                    if (isPropertiesGroup &&
                        context.options.getValue('propertiesFormat') === 'table') {
                        md.push(context.partials.propertiesTable(group.children, context.getTextFromKindString(group.title, true) ===
                            context.getText('kind.event.plural')));
                    }
                    else if (isEnumGroup &&
                        context.options.getValue('enumMembersFormat') === 'table') {
                        md.push(context.partials.enumMembersTable(group.children));
                    }
                    else {
                        pushChildren(group.children, headingLevel + 1);
                    }
                }
            });
        }
    }
    return md.join('\n\n');
}
exports.members = members;
