"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.enumMembersTable = void 0;
const typedoc_1 = require("typedoc");
const markdown_1 = require("../markdown");
const utils_1 = require("../utils");
function enumMembersTable(context, props) {
    const comments = props.map((param) => !!param.comment?.hasVisibleComponent());
    const hasComments = comments.some((value) => Boolean(value));
    const headers = [
        context.getText('kind.enumMember.singular'),
        context.getText('label.value'),
    ];
    if (hasComments) {
        headers.push(context.getText('label.description'));
    }
    const rows = props.map((property) => {
        const propertyType = context.helpers.getDeclarationType(property);
        const row = [];
        const nameColumn = [];
        if (context.options.getValue('namedAnchors') && property.anchor) {
            nameColumn.push(`<a id="${property.anchor}" name="${property.anchor}"></a>`);
        }
        nameColumn.push((0, markdown_1.backTicks)(property.name));
        row.push(nameColumn.join(' '));
        if (propertyType) {
            row.push((0, utils_1.stripLineBreaks)(context.partials.someType(propertyType)));
        }
        if (hasComments) {
            const comments = getComments(property);
            if (comments) {
                row.push((0, utils_1.stripLineBreaks)(context.partials.comment(comments)).replace(/\|/g, '\\|'));
            }
            else {
                row.push('-');
            }
        }
        return `| ${row.join(' | ')} |\n`;
    });
    const output = `\n| ${headers.join(' | ')} |\n| ${headers
        .map(() => ':------')
        .join(' | ')} |\n${rows.join('')}`;
    return output;
}
exports.enumMembersTable = enumMembersTable;
function getComments(property) {
    if (property.type instanceof typedoc_1.ReflectionType) {
        if (property.type?.declaration?.signatures) {
            return property.type?.declaration.signatures[0].comment;
        }
    }
    if (property.signatures) {
        return property.signatures[0].comment;
    }
    return property.comment;
}
