"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parametersTable = void 0;
const typedoc_1 = require("typedoc");
const markdown_1 = require("../markdown");
const utils_1 = require("../utils");
function parametersTable(context, parameters) {
    const parseParams = (current, acc) => {
        const shouldFlatten = current.type?.declaration?.kind === typedoc_1.ReflectionKind.TypeLiteral &&
            current.type?.declaration?.children;
        return shouldFlatten
            ? [...acc, current, ...flattenParams(current)]
            : [...acc, current];
    };
    const flattenParams = (current) => {
        return current.type?.declaration?.children?.reduce((acc, child) => {
            const childObj = {
                ...child,
                name: `${current.name}.${child.name}`,
            };
            return parseParams(childObj, acc);
        }, []);
    };
    const showDefaults = hasDefaultValues(parameters);
    const parsedParams = parameters.reduce((acc, current) => parseParams(current, acc), []);
    const hasComments = parsedParams.some((param) => Boolean(param.comment));
    const headers = [
        context.getText('kind.parameter.singular'),
        context.getText('label.type'),
    ];
    if (showDefaults) {
        headers.push(context.getText('label.defaultValue'));
    }
    if (hasComments) {
        headers.push(context.getText('label.description'));
    }
    const firstOptionalParamIndex = parameters.findIndex((parameter) => parameter.flags.isOptional);
    const rows = [];
    parsedParams.forEach((parameter, i) => {
        const row = [];
        const isOptional = parameter.flags.isOptional ||
            (firstOptionalParamIndex !== -1 && i > firstOptionalParamIndex);
        const rest = parameter.flags.isRest ? '...' : '';
        const optional = isOptional ? '?' : '';
        row.push(`${rest}${(0, markdown_1.backTicks)(parameter.name)}${optional}`);
        if (parameter.type) {
            row.push((0, utils_1.stripLineBreaks)(context.partials.someType(parameter.type), false));
        }
        if (showDefaults) {
            row.push((0, markdown_1.backTicks)(context.helpers.getParameterDefaultValue(parameter)));
        }
        if (hasComments) {
            if (parameter.comment) {
                row.push((0, utils_1.stripLineBreaks)((0, utils_1.formatTableDescriptionCol)(context.partials.comment(parameter.comment))));
            }
            else {
                row.push('-');
            }
        }
        rows.push(row);
    });
    return (0, markdown_1.table)(headers, rows);
}
exports.parametersTable = parametersTable;
function hasDefaultValues(parameters) {
    const defaultValues = parameters.map((param) => param.defaultValue !== '{}' &&
        param.defaultValue !== '...' &&
        !!param.defaultValue);
    return !defaultValues.every((value) => !value);
}
