"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.typeParametersTable = void 0;
const markdown_1 = require("../markdown");
const utils_1 = require("../utils");
function typeParametersTable(context, typeParameters) {
    const hasDefault = typeParameters.some((typeParameter) => Boolean(typeParameter.default));
    const hasComments = typeParameters.some((typeParameter) => Boolean(typeParameter.comment));
    const headers = [context.getText('kind.typeParameter.singular')];
    if (hasDefault) {
        headers.push(context.getText('label.value'));
    }
    if (hasComments) {
        headers.push(context.getText('label.description'));
    }
    const rows = [];
    typeParameters?.forEach((typeParameter) => {
        const row = [];
        const nameCol = [];
        nameCol.push((0, markdown_1.backTicks)(typeParameter.name));
        if (typeParameter.type) {
            nameCol.push(`extends ${context.partials.someType(typeParameter.type)}`);
        }
        row.push(nameCol.join(' '));
        if (hasDefault) {
            if (typeParameter.default) {
                row.push(context.partials.someType(typeParameter.default));
            }
            else {
                row.push('-');
            }
        }
        if (hasComments) {
            if (typeParameter.comment) {
                row.push((0, utils_1.stripLineBreaks)((0, utils_1.formatTableDescriptionCol)(context.partials.comment(typeParameter.comment))));
            }
            else {
                row.push('-');
            }
        }
        rows.push(row);
    });
    return (0, markdown_1.table)(headers, rows);
}
exports.typeParametersTable = typeParametersTable;
