"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MarkdownThemeRenderContext = void 0;
const resources_1 = require("./resources");
/**
 * The render context of the {@link MarkdownTheme}.
 * This follows the implementation of TypeDocs [DefaultThemeRenderContext](https://typedoc.org/api/classes/DefaultThemeRenderContext.html)
 */
class MarkdownThemeRenderContext {
    /**
     * @param page The page this context is created for.
     * @param options The options used by TypeDoc. See TypeDoc's {@link typedoc!Options | Options} Class.
     */
    constructor(theme, page, options) {
        this.theme = theme;
        this.page = page;
        this.options = options;
        /**
         * A set of methods to return strings from specific TypeDoc models.
         *
         * These can be consumed by theme templates and partials using the syntax `context.models.method()`.
         */
        this.helpers = (0, resources_1.helpers)();
        /**
         * The theme's global templates context.
         */
        this.templates = (0, resources_1.templates)(this);
        /**
         * The theme's global partials context.
         */
        this.partials = (0, resources_1.partials)(this);
        this.parseUrl = (url) => {
            return encodeURI(url);
        };
        /**
         * Hook into the TypeDoc rendering system.
         */
        this.hook = (name) => this.theme.owner.markdownHooks.emit(name, this);
    }
    getText(key) {
        return this.theme.getText(key);
    }
    getTextFromKindString(kindString, isPlural = false) {
        return this.theme.getTextFromKindString(kindString, isPlural);
    }
}
exports.MarkdownThemeRenderContext = MarkdownThemeRenderContext;
