import { DeclarationReflection, ProjectReflection, Reflection, ReflectionKind, Theme } from 'typedoc';
import { MarkdownPageEvent, MarkdownRenderer, OutputFileStrategy, TextContentMappings } from '../plugin';
import { RenderTemplate } from './core/urls';
import { MarkdownThemeRenderContext } from './theme-render-context';
/**
 * This is in-built MarkdownTheme which extends TypeDocs Theme class.
 * This follows the implementation of TypeDoc's {@link DefaultTheme}.
 *
 */
export declare class MarkdownTheme extends Theme {
    textMappings: TextContentMappings;
    constructor(renderer: MarkdownRenderer);
    /**
     * Renders a template and page model to a string.
     */
    render(page: MarkdownPageEvent<Reflection>, template: RenderTemplate<MarkdownPageEvent<Reflection>>): string;
    readmeTemplate: (page: MarkdownPageEvent<ProjectReflection>) => string;
    projectTemplate: (page: MarkdownPageEvent<ProjectReflection>) => string;
    reflectionTemplate: (page: MarkdownPageEvent<DeclarationReflection>) => string;
    memberTemplate: (page: MarkdownPageEvent<DeclarationReflection>) => string;
    getRenderContext(page: MarkdownPageEvent<Reflection> | null): MarkdownThemeRenderContext;
    getUrls(project: ProjectReflection): import("./core/urls").UrlMapping<Reflection>[];
    getNavigation(project: ProjectReflection): import("./core/navigation").NavigationItem[];
    getText(key: keyof TextContentMappings): string;
    getTextFromKindString(kindString: string, isPlural?: boolean): string;
    getTemplateMapping(kind: ReflectionKind, outputFileStrategyOverride?: OutputFileStrategy): any;
}
